Module event

Module event 

Structs

EventEnvelope
Wraps an Event with assigned sequence number and timestamp. Serializes to the same JSONL format as the flat Event for backward compat.
EventSink
FlowRunId
Observable
TurnId

Enums

Event
FlowNodeStatus
FlowStatus
LlmCallStatus
NodeEvent