#[non_exhaustive]pub enum ProviderCatalogRefreshOutcome {
NotNeeded,
AlreadyInFlight,
CatalogUpdated(CatalogDelta),
}Expand description
Result of a conditional provider catalog refresh.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NotNeeded
The persisted catalog is already current.
AlreadyInFlight
Another task in this process is refreshing the same provider.
CatalogUpdated(CatalogDelta)
The in-memory catalog was updated from discovery or a newer persisted cache.