Unified notification system for atman.
ⓘ
use atman_runtime::notify::{self, NotifyLocation, NotifyStack};
notify!(info, "copied {} chars to clipboard", n);
notify!(warn, location = Inline, stack = dedupe("key", 30_000), "index unavailable");
notify!(success, location = Toast, "todo marked done");
notify!(debug, target: "auto_snapshot", "{} @ {}", name, rev);Macros
- notify
- Emit a notification through the global notifier.
Structs
- CliSink
- Sink that prints to stdout/stderr based on level.
- Composite
Sink - Fan-out to multiple sinks.
- LogSink
- Sink that appends JSONL lines to a session log file.
- Noop
Sink - Notification
- Scoped
Sink - RAII guard: installs a sink and restores the previous one on drop.
- Toast
Collector - Sink that collects notifications into a shared buffer for rendering as toasts in the boot animation. Does not print to stdout/stderr.